@@ -9,7 +9,7 @@ import (
 
 	"github.com/constabulary/gb"
 	"github.com/constabulary/gb/cmd"
-	"github.com/constabulary/gb/log"
+	"github.com/constabulary/gb/debug"
 )
 
 var (
@@ -24,10 +24,7 @@ const (
 )
 
 func init() {
-	fs.BoolVar(&log.Quiet, "q", log.Quiet, "suppress log messages below ERROR level")
-	fs.BoolVar(&log.Verbose, "v", log.Verbose, "enable log levels below INFO level")
 	fs.StringVar(&cwd, "R", cmd.MustGetwd(), "set the project root") // actually the working directory to start the project root search
-
 	fs.Usage = usage
 }
 
@@ -39,12 +36,12 @@ func registerCommand(command *cmd.Command) {
 	commands[command.Name] = command
 }
 
-func main() {
-	fatalf := func(format string, args ...interface{}) {
-		fmt.Fprintf(os.Stderr, "FATAL: "+format+"\n", args...)
-		os.Exit(1)
-	}
+func fatalf(format string, args ...interface{}) {
+	fmt.Fprintf(os.Stderr, "FATAL: "+format+"\n", args...)
+	os.Exit(1)
+}
 
+func main() {
 	args := os.Args
 	if len(args) < 2 || args[1] == "-h" {
 		fs.Usage()
@@ -66,9 +63,6 @@ func main() {
 		}
 		command = &cmd.Command{
 			Run: func(ctx *gb.Context, args []string) error {
-				if len(args) < 1 {
-					return fmt.Errorf("plugin: no command supplied")
-				}
 				args = append([]string{plugin}, args...)
 
 				env := cmd.MergeEnv(os.Environ(), map[string]string{
@@ -137,11 +131,12 @@ func main() {
 		args = cmd.ImportPaths(ctx, cwd, args)
 	}
 
-	log.Debugf("args: %v", args)
+	debug.Debugf("args: %v", args)
 	if err := command.Run(ctx, args); err != nil {
 		if !noDestroyContext {
-			ctx.Destroy()
+			defer ctx.Destroy()
 		}
 		fatalf("command %q failed: %v", name, err)
 	}
+	return
 }
